==> cms-db_v0.7.9.tar.gz: admin/locales/de/locale_variables.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['variables'] = array();

$locale['variables']['title'] = 'Variablen';
$locale['variables']['desc'] = 'Alle Variablen können im <a href="%s">Template</a> verwendet werden, alle bis auf PAGECONTENT auch in den <a href="%s">Seiten</a>. In Gästebucheinträgen und Blog-Artikeln werden keine Variablen ersetzt.';

$locale['variables']['desc_p-allowed'] = 'kann in einem Absatz verwendet werden';
$locale['variables']['desc_p-alone'] = 'kann in einem Absatz verwendet werden, muss aber dessen einziger Inhalt sein';
$locale['variables']['desc_p-disallowed'] = 'darf nicht in einem Absatz verwendet werden';
$locale['variables']['desc_p-needed'] = 'muss in einem Absatz verwendet werden und dessen einziger Inhalt sein';

$locale['variables']['desc_topmenu'] = 'Erstellt ein Menü der Seiten der obersten Ebene';
$locale['variables']['desc_completesubmenu'] = 'Erstellt ein Menü, das alle Unterseiten der aktuellen Seite der obersten Ebene anzeigt';
$locale['variables']['desc_foldingsubmenu'] = 'Erstellt ein Menü, das je nach geöffneter Unterseite die Unterseiten der aktuellen Seite der obersten Ebene anzeigt';
$locale['variables']['desc_completemenu'] = 'Erstellt ein komplettes Menü für die Website';
$locale['variables']['desc_foldingmenu'] = 'Erstellt ein Menü für die ganze Website, das je nach aktuell geöffneter Seite die Unterseiten anzeigt';
$locale['variables']['desc_pagesearch'] = 'Zeigt ein Suchfeld an';
$locale['variables']['desc_pagetitle'] = 'Zeigt den Namen der aktuellen Seite an';
$locale['variables']['desc_fulltitle'] = 'Name der aktuellen Seite mit Seitenstruktur';
$locale['variables']['desc_breadcrumbs'] = 'Wie %%FULLTITLE%%, aber mit Links zu den einzelnen Seiten';
$locale['variables']['desc_pagecontent'] = 'Zeigt den Inhalt der aktuellen Seite an';
$locale['variables']['desc_lastedit'] = 'Zeigt das Datum der letzten Änderung an der aktuellen Seite an';
$locale['variables']['desc_pagecount'] = 'Zählt die Anzahl der Seitenaufrufe und zeigt sie an';
$locale['variables']['desc_counter'] = 'Zeigt die Anzahl der Besucher an';
$locale['variables']['desc_sitemap'] = 'Erstellt eine Sitemap, ein umgebender Absatz wird automatisch entfernt';
$locale['variables']['desc_mailform'] = 'Zeigt ein Kontaktformular an, das E-Mails an die angegebene Adresse ADDRESS sendet, ein umgebender Absatz wird automatisch entfernt';
$locale['variables']['desc_guestbook'] = 'Zeigt ein Gästebuch mit Formular an, der Zeichensatz muss UTF-8 sein und ein ein umgebender Absatz wird automatisch entfernt';
$locale['variables']['desc_blog'] = 'Zeigt das Blog an, der Zeichensatz muss UTF-8 sein und ein ein umgebender Absatz wird automatisch entfernt';
$locale['variables']['desc_latestblogarticles'] = 'Zeigt eine Liste der neuesten Blogeinträge ein, PAGE ist die Kurz-URL der Seite, auf der das Blog angezeigt wird';
$locale['variables']['desc_tagcloud'] = 'Zeigt eine Schlagwortwolke für das Blog an, PAGE ist die Kurz-URL der Seite, auf der das Blog angezeigt wird';
$locale['variables']['desc_sectionlist'] = 'Zeigt eine Linkliste der direkten Unterseiten der aktuellen Seite an, ein umgebender Absatz wird automatisch entfernt';
$locale['variables']['desc_loginform'] = 'Zeigt ein Anmeldeformular an, ein umgebender Absatz wird automatisch entfernt';
$locale['variables']['desc_include'] = 'Zeigt den Include NAME an, ein umgebender Absatz wird automatisch entfernt';
$locale['variables']['desc_redirect'] = 'Weiterleitung auf die angegebene URL, der Seiteninhalt wird nicht angezeigt';
$locale['variables']['desc_forcelanguage'] = 'Ändert die Sprache für generierte Inhalte auf den angegebenen LANGCODE';
$locale['variables']['desc_urlsettings'] = 'Gibt die URL-Einstellungen aus';
$locale['variables']['desc_condition'] = 'Der Inhalt zwischen den zwei Variablen wird nur angezeigt, wenn die PHP-Bedingung COND wahr ist, %%CONDITION-(COND)%% und %%ENDCONDITION%% müssen jeweils allein in einem Absatz stehen';

?>

==> cms-db_v0.8.1.tar.gz: admin/locales/de/locale_variables.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['variables'] = array();

$locale['variables']['title'] = 'Variablen';
$locale['variables']['desc'] = 'Alle Variablen können im <a href="%s">Template</a> verwendet werden, alle bis auf PAGECONTENT auch in den <a href="%s">Seiten</a>. In Gästebucheinträgen und Blog-Artikeln werden keine Variablen ersetzt.';

$locale['variables']['title_variables-menu'] = 'Menüs';
$locale['variables']['title_variables-contentstructure'] = 'Inhalt und Struktur';
$locale['variables']['title_variables-dynamic'] = 'Dynamische Inhalte';
$locale['variables']['title_variables-blog'] = 'Blog';
$locale['variables']['title_variables-misc'] = 'Verschiedenes';

$locale['variables']['desc_p-allowed'] = 'kann in einem Absatz verwendet werden';
$locale['variables']['desc_p-alone'] = 'kann in einem Absatz verwendet werden, muss aber dessen einziger Inhalt sein';
$locale['variables']['desc_p-disallowed'] = 'darf nicht in einem Absatz verwendet werden';
$locale['variables']['desc_p-needed'] = 'muss in einem Absatz verwendet werden und dessen einziger Inhalt sein';

$locale['variables']['desc_topmenu'] = 'Erstellt ein Menü der Seiten der obersten Ebene';
$locale['variables']['desc_completesubmenu'] = 'Erstellt ein Menü, das alle Unterseiten der aktuellen Seite der obersten Ebene anzeigt';
$locale['variables']['desc_foldingsubmenu'] = 'Erstellt ein Menü, das je nach geöffneter Unterseite die Unterseiten der aktuellen Seite der obersten Ebene anzeigt';
$locale['variables']['desc_completemenu'] = 'Erstellt ein komplettes Menü für die Website';
$locale['variables']['desc_foldingmenu'] = 'Erstellt ein Menü für die ganze Website, das je nach aktuell geöffneter Seite die Unterseiten anzeigt';
$locale['variables']['desc_pagesearch'] = 'Zeigt ein Suchfeld an';
$locale['variables']['desc_pagetitle'] = 'Zeigt den Namen der aktuellen Seite an';
$locale['variables']['desc_fulltitle'] = 'Name der aktuellen Seite mit Seitenstruktur';
$locale['variables']['desc_breadcrumbs'] = 'Wie %%FULLTITLE%%, aber mit Links zu den einzelnen Seiten';
$locale['variables']['desc_pagecontent'] = 'Zeigt den Inhalt der aktuellen Seite an';
$locale['variables']['desc_lastedit'] = 'Zeigt das Datum der letzten Änderung an der aktuellen Seite an';
$locale['variables']['desc_pagecount'] = 'Zählt die Anzahl der Seitenaufrufe und zeigt sie an';
$locale['variables']['desc_counter'] = 'Zeigt die Anzahl der Besucher an';
$locale['variables']['desc_sitemap'] = 'Erstellt eine Sitemap, ein umgebender Absatz wird automatisch entfernt';
$locale['variables']['desc_mailform'] = 'Zeigt ein Kontaktformular an, das E-Mails an die angegebene Adresse ADDRESS sendet, ein umgebender Absatz wird automatisch entfernt';
$locale['variables']['desc_guestbook'] = 'Zeigt ein Gästebuch mit Formular an, der Zeichensatz muss UTF-8 sein und ein ein umgebender Absatz wird automatisch entfernt';
$locale['variables']['desc_blog'] = 'Zeigt das Blog an, der Zeichensatz muss UTF-8 sein und ein ein umgebender Absatz wird automatisch entfernt';
$locale['variables']['desc_latestblogarticles'] = 'Zeigt eine Liste der neuesten Blogeinträge ein, PAGE ist die Kurz-URL der Seite, auf der das Blog angezeigt wird';
$locale['variables']['desc_tagcloud'] = 'Zeigt eine Schlagwortwolke für das Blog an, PAGE ist die Kurz-URL der Seite, auf der das Blog angezeigt wird';
$locale['variables']['desc_completeblogfeed'] = 'Zeigt einen Link zum kompletten Blog-Feed an, PAGE ist die Kurz-URL der Seite, auf der das Blog angezeigt wird';
$locale['variables']['desc_allblogfeeds'] = 'Zeigt eine Liste aller verfügbaren Blog-Feeds an (nach Tags), PAGE ist die Kurz-URL der Seite, auf der das Blog angezeigt wird, ein umgebender Absatz wird automatisch entfernt';
$locale['variables']['desc_contextblogfeeds'] = 'Zeigt eine kontextabhängige Liste der verfügbaren Blog-Feeds an (nur im Blog), PAGE ist die Kurz-URL der Seite, auf der das Blog angezeigt wird, ein umgebender Absatz wird automatisch entfernt';
$locale['variables']['desc_sectionlist'] = 'Zeigt eine Liste von Links zu direkten Unterseiten der aktuellen Seite, ein umgebender Absatz wird automatisch entfernt';
$locale['variables']['desc_loginform'] = 'Zeigt ein Anmeldeformular an, ein umgebender Absatz wird automatisch entfernt';
$locale['variables']['desc_include'] = 'Zeigt den Include NAME an, ein umgebender Absatz wird automatisch entfernt, späte Includes werden zum letztmöglichen Zeitpunkt ersetzt';
$locale['variables']['desc_redirect'] = 'Weiterleitung auf die angegebene URL, der Seiteninhalt wird nicht angezeigt';
$locale['variables']['desc_forcelanguage'] = 'Ändert die Sprache für generierte Inhalte auf den angegebenen LANGCODE';
$locale['variables']['desc_urlsettings'] = 'Gibt die URL-Einstellungen aus';
$locale['variables']['desc_completeurl'] = 'Zeigt die komplette URL der aktuellen Seite an (mit Domain)';
$locale['variables']['desc_condition'] = 'Der Inhalt zwischen den zwei Variablen wird nur angezeigt, wenn die PHP-Bedingung COND wahr ist, %%CONDITION-(COND)%% und %%ENDCONDITION%% müssen jeweils allein in einem Absatz stehen';

?>
